@@ -289,7 +289,7 @@ int parse_options(int argc, char *untrusted_argv[], int *input_fds,
         { "show-keyring", false, true },
         { "show-keyserver-urls", true, true },
         { "show-notations", true, true },
-        { "show-photos", false, true },
+        { "show-photos", true, true },
         { "show-policy-urls", true, true },
         { "show-sig-expire", true, true },
         { "show-std-notations", true, true },
@@ -309,7 +309,7 @@ int parse_options(int argc, char *untrusted_argv[], int *input_fds,
     static struct listopt const allowed_verify_options[] = {
         { "show-keyserver-urls", true, true },
         { "show-notations", true, true },
-        { "show-photos", false, true },
+        { "show-photos", true, true },
         { "show-policy-urls", true, true },
         { "show-std-notations", true, true },
         { "show-standard-notations", true, true },
