@@ -70,11 +70,9 @@ enum {
     opt_no_tty,
     opt_no_verbose,
     opt_openpgp,
-    opt_passphrase_fd,
     opt_personal_cipher_preferences,
     opt_personal_compress_preferences,
     opt_personal_digest_preferences,
-    opt_pgp2,
     opt_pgp6,
     opt_pgp7,
     opt_pgp8,
@@ -143,7 +141,6 @@ static const int gpg_allowed_options[] = {
     opt_compress_algo,
     opt_default_recipient_self,
     opt_digest_algo,
-    opt_disable_mdc,
     opt_emit_version,
     opt_enable_progress_filter,
     opt_encrypt_to,
@@ -152,9 +149,6 @@ static const int gpg_allowed_options[] = {
     opt_export_ssh,
     opt_fingerprint,
     opt_fixed_list_mode,
-    opt_force_mdc,
-    opt_force_v3_sigs,
-    opt_force_v4_certs,
     opt_gnupg,
     opt_hidden_encrypt_to,
     opt_list_config,
@@ -166,7 +160,6 @@ static const int gpg_allowed_options[] = {
     opt_max_output,
     opt_no_auto_check_trustdb,
     opt_no_comments,
-    opt_no_comments,
     opt_no_default_recipient,
     opt_no_emit_version,
     opt_no_encrypt_to,
@@ -174,16 +167,13 @@ static const int gpg_allowed_options[] = {
     opt_no_force_v4_certs,
     opt_no_greeting,
     opt_no_secmem_warning,
-    opt_no_sk_comments,
     opt_no_skip_hidden_recipients,
     opt_no_throw_keyids,
-    opt_no_tty,
     opt_no_verbose,
     opt_openpgp,
     opt_personal_cipher_preferences,
     opt_personal_compress_preferences,
     opt_personal_digest_preferences,
-    opt_pgp2,
     opt_pgp6,
     opt_pgp7,
     opt_pgp8,
@@ -205,7 +195,6 @@ static const int gpg_allowed_options[] = {
     opt_try_all_secrets,
     opt_try_secret_key,
     opt_unwrap,
-    opt_use_agent,
     opt_verify,
     opt_verify_options,
     opt_version,
@@ -319,7 +308,6 @@ static const struct option gpg_long_options[] = {
     {"personal-cipher-preferences", 1, 0, opt_personal_cipher_preferences},
     {"personal-compress-preferences", 1, 0, opt_personal_compress_preferences},
     {"personal-digest-preferences", 1, 0, opt_personal_digest_preferences},
-    {"pgp2", 0, 0, opt_pgp2},
     {"pgp6", 0, 0, opt_pgp6},
     {"pgp7", 0, 0, opt_pgp7},
     {"pgp8", 0, 0, opt_pgp8},
